==> readmeter-3.0.0-28-2-sources.jar: com/aote/rs/ImageUtil.java <==
package com.aote.rs;

import com.af.plugins.CommonTools;
import com.af.plugins.JsonTools;
import com.af.plugins.RestTools;
import com.aote.rs.ImageData;
import org.json.JSONArray;
import org.json.JSONObject;

import javax.imageio.ImageIO;
import javax.ws.rs.PathParam;
import java.awt.*;
import java.awt.image.BufferedImage;
import java.io.*;

public class ImageUtil {

        /**
         * 地址
         */
        private static final String PICTURE_URL = "http://47.105.172.196:8000/";
        /**
         * 用户名
         */
        private static final String USER_NAME = "admin";
        /**
         * 密码
         */
        private static final String PASSWORD = "admin";

        /**
         * 图像数据上传，获取文本
         * @param id 请求访问的唯一标识
         * @param imageData 图像信息
         * @return 识别的文本结果
         */
        public static String getImageText(String id,ImageData imageData){
                JSONObject params = new JSONObject();
                if(imageData.getImageType().equals("jpg")){
                        params.put("PictureType",16);
                } else {
                        params.put("PictureType",32);
                }
                JSONObject imageRequestData = new JSONObject();
                imageRequestData.put("SizeRow",imageData.getWidth());
                imageRequestData.put("SizeCol",imageData.getHeight());
                imageRequestData.put("imData",imageData.getBase64Str());
                params.put("ImageData",imageRequestData);
                params.put("PicIdx",imageData.getName());
                params.put("UserID",id);
                params.put("DataType",4);
                System.out.println("params:"+params.toString());
                JSONObject result = JsonTools.convertToJson(RestTools.post(PICTURE_URL,params));
                String identifyResult = result.getString("IdentifyResult");
                identifyResult = identifyResult.substring(1,identifyResult.length() - 1).replace(" ","");
                return identifyResult;
        }

        /**
         * 识别软件状态查询
         * @param id 请求访问的唯一标识
         * @return 结果
         */
        public static JSONObject getStatus(String id){
                JSONObject requestParams = new JSONObject();
                requestParams.put("DataType",2);
                requestParams.put("UserName",USER_NAME);
                requestParams.put("Passwd",PASSWORD);
                requestParams.put("UserID",id);
                JSONObject requestResult = new JSONObject(RestTools.post(PICTURE_URL,requestParams));
                JSONObject result = new JSONObject();
                if(requestResult.has("ServiceStatus")){
                        if(requestResult.getInt("ServiceStatus") == 1){
                                result.put("status","正常");
                        } else {
                                result.put("status","未就绪");
                                result.put("message",requestResult.toString());
                        }
                } else {
                        result.put("status","服务异常");
                }
                return result;
        }

        public static void main(String[] args) throws IOException {
                 //获取请求访问的唯一标识
                String id = CommonTools.getUUID();
                //获取识别软件就绪状态
                JSONObject statusObject = getStatus(id);
                String status = statusObject.getString("status");
                if(status.equals("正常")){
                        System.out.println(getImageText(id, ImageData.getImageData("D:\\1.jpg")));
                } else if(status.equals("未就绪")){
                        throw new RuntimeException("识别软件未就绪！");
                } else {
                        throw new RuntimeException("网络异常:"+statusObject.getString("message"));
                }
        }
}

==> readmeter-3.0.0-29-sources.jar: com/aote/rs/ImageUtil.java <==
package com.aote.rs;

import com.af.plugins.CommonTools;
import com.af.plugins.JsonTools;
import com.af.plugins.RestTools;
import com.aote.rs.ImageData;
import org.json.JSONArray;
import org.json.JSONObject;

import javax.imageio.ImageIO;
import javax.ws.rs.PathParam;
import java.awt.*;
import java.awt.image.BufferedImage;
import java.io.*;
import org.apache.log4j.Logger;

public class ImageUtil {
     private static Logger log = Logger.getLogger(MobileServicePlugin.class);
        /**
         * 地址
         */
        private static final String PICTURE_URL = "http://47.105.172.196:8000";
        /**
         * 用户名
         */
        private static final String USER_NAME = "admin";
        /**
         * 密码
         */
        private static final String PASSWORD = "admin";

        /**
         * 图像数据上传，获取文本
         * @param id 请求访问的唯一标识
         * @param imageData 图像信息
         * @return 识别的文本结果
         */
        public static String getImageText(String id,ImageData imageData){
                JSONObject params = new JSONObject();
                if(imageData.getImageType().equals("jpg")){
                        params.put("PictureType",16);
                } else {
                        params.put("PictureType",32);
                }
                JSONObject imageRequestData = new JSONObject();
                imageRequestData.put("SizeRow",imageData.getWidth());
                imageRequestData.put("SizeCol",imageData.getHeight());
                imageRequestData.put("imData",imageData.getBase64Str());
                params.put("ImageData",imageRequestData);
                params.put("PicIdx",imageData.getName());
                params.put("UserID",id);
                params.put("DataType",4);
                log.debug("getImageText:"+params);
                JSONObject result = JsonTools.convertToJson(RestTools.post(PICTURE_URL,params));
                log.debug("result:"+result);
                String identifyResult = result.getString("IdentifyResult");
                identifyResult = identifyResult.substring(1,identifyResult.length() - 1).replace(" ","");
                return identifyResult;
        }

        /**
         * 识别软件状态查询
         * @param id 请求访问的唯一标识
         * @return 结果
         */
        public static JSONObject getStatus(String id){
                JSONObject requestParams = new JSONObject();
                requestParams.put("DataType",2);
                requestParams.put("UserName",USER_NAME);
                requestParams.put("Passwd",PASSWORD);
                requestParams.put("UserID",id);
                JSONObject requestResult = new JSONObject(RestTools.post(PICTURE_URL,requestParams));
                JSONObject result = new JSONObject();
                if(requestResult.has("ServiceStatus")){
                        if(requestResult.getInt("ServiceStatus") == 1){
                                result.put("status","正常");
                        } else {
                                result.put("status","未就绪");
                                result.put("message",requestResult.toString());
                        }
                } else {
                        result.put("status","服务异常");
                }
                return result;
        }

        public static void main(String[] args) throws IOException {
                 //获取请求访问的唯一标识
                String id = CommonTools.getUUID();
                //获取识别软件就绪状态
                JSONObject statusObject = getStatus(id);
                String status = statusObject.getString("status");
                if(status.equals("正常")){
                        System.out.println(getImageText(id, ImageData.getImageData("D:\\1.jpg")));
                } else if(status.equals("未就绪")){
                        throw new RuntimeException("识别软件未就绪！");
                } else {
                        throw new RuntimeException("网络异常:"+statusObject.getString("message"));
                }
        }
}
